@@ -1,13 +1,13 @@
 import gtk
 
-from kiwi.ui.widgets.list import Column, List
+from kiwi.ui.objectlist import Column, ObjectList
 
 class Fruit:
     def __init__(self, name, cost):
         self.name = name
         self.cost = cost
-        
-fruits = List([Column('name', data_type=str, editable=True,
+
+fruits = ObjectList([Column('name', data_type=str, editable=True,
                       expand=True),
                Column('cost', data_type=int, editable=True)])
 
