@@ -26,6 +26,7 @@
 """Data type converters with locale and currency support"""
 
 import datetime
+import decimal
 import locale
 import sys
 import time
@@ -150,6 +151,19 @@ class _StringConverter(BaseConverter):
 
 converter.add(_StringConverter)
 
+class _UnicodeConverter(BaseConverter):
+    type = unicode
+
+    def as_string(self, value, format=None):
+        if format is None:
+            format = u'%s'
+        return format % value
+
+    def from_string(self, value):
+        return unicode(value)
+
+converter.add(_UnicodeConverter)
+
 class _IntConverter(BaseConverter):
     type = int
 
@@ -218,10 +232,7 @@ class _FloatConverter(BaseConverter):
         # Check so we only have one decimal point
         decimal_point = conv["decimal_point"]
         decimal_points = value.count(decimal_point)
-        if decimal_points == 1:
-            # Replace the decimal point with a dot, which float() can handle
-            value = value.replace(decimal_point, '.')
-        elif decimal_points > 1:
+        if decimal_points > 1:
             raise ValidationError(
                 'You have more than one decimal point ("%s") '
                 ' in your number "%s"' % (decimal_point, value))
@@ -262,7 +273,7 @@ class _FloatConverter(BaseConverter):
     def as_string(self, value, format=None):
         """Convert a float to a string"""
         if format is None:
-            format = '%f'
+            format = '%g'
         return lformat(format, value)
 
     def from_string(self, value):
@@ -282,6 +293,23 @@ class _FloatConverter(BaseConverter):
 
 converter.add(_FloatConverter)
 
+class _DecimalConverter(_FloatConverter):
+    type = decimal.Decimal
+    def from_string(self, value):
+        if value == '':
+            return ValueUnset
+
+        value = self._filter_locale(value)
+
+        try:
+            retval = decimal.Decimal(value)
+        except decimal.InvalidOperation:
+            raise ValidationError("This field requires a number")
+
+        return retval
+
+converter.add(_DecimalConverter)
+
 class _BaseDateTimeConverter(BaseConverter):
     """
     Abstract class for converting datatime objects to and from strings
@@ -312,7 +340,7 @@ class _BaseDateTimeConverter(BaseConverter):
                 return cmp(a, b)
         return _datecmp
 
-    def _get_format(self):
+    def get_format(self):
         if sys.platform == 'win32':
             return self.date_format
         else:
@@ -321,7 +349,7 @@ class _BaseDateTimeConverter(BaseConverter):
     def as_string(self, value, format=None):
         "Convert a date to a string"
         if format is None:
-            format = self._get_format()
+            format = self.get_format()
 
         if value is None:
             return ''
@@ -338,7 +366,7 @@ class _BaseDateTimeConverter(BaseConverter):
         # perhaps we should add macros, to be able to write
         # yyyy instead of %Y
 
-        format = self._get_format()
+        format = self.get_format()
         try:
             # time.strptime (python 2.4) does not support %r
             # pending SF bug #1396946
@@ -390,12 +418,12 @@ class _ObjectConverter(BaseConverter):
     from_string = None
 converter.add(_ObjectConverter)
 
-class currency(float):
+class currency(decimal.Decimal):
     """
     A datatype representing currency, used together with the list and
     the framework
     """
-    _converter = converter.get_converter(float)
+    _converter = converter.get_converter(decimal.Decimal)
 
     def __new__(cls, value):
         """
@@ -407,14 +435,17 @@ class currency(float):
             currency_symbol = conv.get('currency_symbol')
             text = value.strip(currency_symbol)
             value = currency._converter.from_string(text)
-        elif not isinstance(value, (int, float, long)):
+        elif isinstance(value, float):
+            value = str(value)
+        elif not isinstance(value, (int, long, decimal.Decimal)):
             raise TypeError(
                 "cannot convert %r of type %s to a currency" % (
                 value, type(value)))
-        return float.__new__(cls, value)
+
+        return decimal.Decimal.__new__(cls, value)
 
     def format(self, symbol=True, precision=None):
-        value = float(self)
+        value = decimal.Decimal(self)
 
         conv = locale.localeconv()
 
@@ -547,7 +578,3 @@ def format_price(value, symbol=True, precision=None):
     """
 
     return currency(value).format(symbol, precision)
-
-if __name__ == '__main__':
-    print currency(10.0)
-    print currency(10.3)
