@@ -1,7 +1,7 @@
 #
 # Kiwi: a Framework and Enhanced Widgets for Python
 #
-# Copyright (C) 2005 Async Open Source
+# Copyright (C) 2005-2006 Async Open Source
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -39,15 +39,19 @@ from gazpacho.properties import prop_registry, CustomProperty, StringType
 from kiwi import _warn
 from kiwi.datatypes import currency
 from kiwi.environ import environ
+from kiwi.ui.objectlist import Column, ObjectList
 from kiwi.ui.widgets.checkbutton import CheckButton
-from kiwi.ui.widgets.combobox import ComboBox, ComboBoxEntry
+from kiwi.ui.widgets.combo import ProxyComboEntry, ProxyComboBox, ProxyComboBoxEntry
 from kiwi.ui.widgets.entry import Entry
 from kiwi.ui.widgets.label import Label
-from kiwi.ui.widgets.list import Column, List
 from kiwi.ui.widgets.radiobutton import RadioButton
 from kiwi.ui.widgets.spinbutton import SpinButton
 from kiwi.ui.widgets.textview import TextView
 
+# Backwards compatibility + pyflakes
+from kiwi.ui.widgets.combobox import ComboBox, ComboBoxEntry
+from kiwi.ui.widgets.list import List
+
 _ = gettext.gettext
 
 class Builder(ObjectBuilder):
@@ -90,6 +94,7 @@ class GazpachoWidgetTree:
     def get_widget(self, name):
         """Retrieves the named widget from the View (or glade tree)"""
         name = name.replace('.', '_')
+        name = name.replace('-', '_')
         widget = self._tree.get_widget(name)
         if widget is None:
             raise AttributeError(
@@ -151,46 +156,60 @@ class DataTypeAdaptor(PropertyCustomEditor):
 
 class SpinBtnDataType(DataTypeAdaptor):
     def get_data_types(self):
-        return [(_('Integer'), int),
-                (_('Float'), float),
-                (_('Currency'), currency)]
+        return [
+            (_('Integer'), int),
+            (_('Float'), float),
+            (_('Currency'), currency)
+            ]
 
 class EntryDataType(DataTypeAdaptor):
     def get_data_types(self):
-        return [(_('Integer'), int),
-                (_('Float'), float),
-                (_('String'), str),
-                (_('Currency'), currency),
-                (_('Date'), datetime.date),
-                (_('Datetime'), datetime.datetime),
-                (_('Time'), datetime.time),
-                (_('Object'), object)]
+        return [
+            (_('String'), str),
+            (_('Unicode'), unicode),
+            (_('Integer'), int),
+            (_('Float'), float),
+            (_('Currency'), currency),
+            (_('Date'), datetime.date),
+            (_('Datetime'), datetime.datetime),
+            (_('Time'), datetime.time),
+            (_('Object'), object)
+            ]
 
 class TextViewDataType(DataTypeAdaptor):
     def get_data_types(self):
-        return [(_('Integer'), int),
-                (_('Float'), float),
-                (_('Date'), datetime.date),
-                (_('String'), str)]
+        return [
+            (_('String'), str),
+            (_('Unicode'), unicode),
+            (_('Integer'), int),
+            (_('Float'), float),
+            (_('Date'), datetime.date),
+            ]
 
 class ComboBoxDataType(DataTypeAdaptor):
     def get_data_types(self):
-        return [(_('Boolean'), bool),
-                (_('String'), str),
-                (_('Integer'), int),
-                (_('Float'), float),
-                (_('Object'), object)]
+        return [
+            (_('String'), str),
+            (_('Unicode'), unicode),
+            (_('Boolean'), bool),
+            (_('Integer'), int),
+            (_('Float'), float),
+            (_('Object'), object)
+            ]
 
 class LabelDataType(DataTypeAdaptor):
     def get_data_types(self):
-        return [(_('Boolean'), bool),
-                (_('String'), str),
-                (_('Integer'), int),
-                (_('Float'), float),
-                (_('Date'), datetime.date),
-                (_('Datetime'), datetime.datetime),
-                (_('Time'), datetime.time),
-                (_('Currency'), currency)]
+        return [
+            (_('String'), str),
+            (_('Unicode'), unicode),
+            (_('Boolean'), bool),
+            (_('Integer'), int),
+            (_('Float'), float),
+            (_('Date'), datetime.date),
+            (_('Datetime'), datetime.datetime),
+            (_('Time'), datetime.time),
+            (_('Currency'), currency)
+            ]
 
 class DataTypeProperty(CustomProperty, StringType):
     translatable = False
@@ -214,20 +233,29 @@ class KiwiColumnAdapter(Adapter):
         return Column(name)
 adapter_registry.register_adapter(KiwiColumnAdapter)
 
-class ListAdapter(PythonWidgetAdapter):
-    object_type = List
-adapter_registry.register_adapter(ListAdapter)
+class ObjectListAdapter(PythonWidgetAdapter):
+    object_type = ObjectList
+    def construct(self, name, gtype, properties):
+        if gtype == List:
+            gtype == ObjectList
+        return super(ObjectListAdapter, self).construct(name, gtype,
+                                                        properties)
+adapter_registry.register_adapter(ObjectListAdapter)
 
 # Register widgets which have data-type and model-attributes
 # ComboBox is a special case, it needs to inherit from another
 # adapter and need to support two types.
 class KiwiComboBoxAdapter(ComboBoxAdapter):
-    object_type = ComboBox, ComboBoxEntry
+    object_type = ProxyComboBox, ProxyComboBoxEntry
     def construct(self, name, gtype, properties):
-        if gtype == ComboBox.__gtype__:
-            object_type = ComboBox
-        elif gtype == ComboBoxEntry.__gtype__:
-            object_type = ComboBoxEntry
+        if gtype in (ProxyComboBox.__gtype__,
+                     ComboBox.__gtype__):
+            object_type = ProxyComboBox
+        elif gtype in (ProxyComboBoxEntry.__gtype__,
+                       ComboBoxEntry.__gtype__):
+            object_type = ProxyComboBoxEntry
+        else:
+            raise AssertionError("Unknown ComboBox GType: %r" % gtype)
 
         obj = object_type()
         obj.set_name(name)
@@ -237,8 +265,9 @@ adapter_registry.register_adapter(KiwiComboBoxAdapter)
 for gobj, editor in [(Entry, EntryDataType),
                      (CheckButton, None),
                      (Label, LabelDataType),
-                     (ComboBox, ComboBoxDataType),
-                     (ComboBoxEntry, ComboBoxDataType),
+                     (ProxyComboBox, ComboBoxDataType),
+                     (ProxyComboBoxEntry, ComboBoxDataType),
+                     (ProxyComboEntry, ComboBoxDataType),
                      (SpinButton, SpinBtnDataType),
                      (RadioButton, None),
                      (TextView, TextViewDataType)]:
@@ -265,7 +294,7 @@ for gobj, editor in [(Entry, EntryDataType),
     # Register custom adapters, since gobject.new is broken in 2.6
     # Used by loader, eg in gazpacho and in applications
     # ComboBox is registered above
-    if gobj == ComboBox:
+    if gobj == ProxyComboBox:
         continue
 
     klass = type('Kiwi%sAdapter', (PythonWidgetAdapter,),
