@@ -9,7 +9,7 @@ class ArgTest(unittest.TestCase):
         f('str')
         self.assertRaises(TypeError, f, None)
         self.assertRaises(TypeError, f, 1)
-        
+
     def testTwoArgs(self):
         f = argcheck(str, int)(lambda s, i: None)
         f('str', 1)
@@ -33,30 +33,30 @@ class ArgTest(unittest.TestCase):
 
         f2 = lambda a, b='str': None
         self.assertRaises(TypeError, argcheck, f2)
-        
+
     def testKwargs(self):
         self.assertRaises(TypeError, argcheck, lambda **kw: None)
 
     def testUserDefined(self):
         class Payment(object):
             pass
-    
+
         @argcheck(Payment, str)
         def pay(payment, description):
             pass
         pay(Payment(), 'foo')
         self.assertRaises(TypeError, 'bar', 'bar')
         self.assertRaises(TypeError, Payment(), Payment())
-        
+
     def testClass(self):
         class Custom(object):
             pass
-        
+
         class Test:
             @argcheck(int, int)
             def method1(self, foo, bar):
                 return foo + bar
-            
+
             @argcheck(Custom, int, datetime.datetime, int, int,
                       float, float)
             def method2(self, a, b, c, d, e, f, g=0.0):
@@ -66,6 +66,10 @@ class ArgTest(unittest.TestCase):
             def method3(self, s, date=None, date2=None):
                 return
 
+            @argcheck(percent)
+            def method4(self, n):
+                return n
+
         t = Test()
         self.assertEqual(t.method1(1, 2), 3)
         self.assertRaises(TypeError, t.method1, None, None)
@@ -78,11 +82,16 @@ class ArgTest(unittest.TestCase):
         t.method3(s='foo')
         t.method3(s='bar', date=None)
         t.method3(s='baz', date=None, date2=None)
+        t.method4(n=0)
+        t.method4(n=50)
+        t.method4(n=100)
         self.assertRaises(TypeError, t.method3, 'noggie', True)
         self.assertRaises(TypeError, t.method3, 'boogie', None, True)
         self.assertRaises(TypeError, t.method3, s='noggie', date2=True)
         self.assertRaises(TypeError, t.method3, s='boogie',
                           date=None, date2=True)
+        self.assertRaises(ValueError, t.method4, -1)
+        self.assertRaises(ValueError, t.method4, 101)
 
     def testNone(self):
         @argcheck(datetime.datetime)
@@ -109,6 +118,26 @@ class ArgTest(unittest.TestCase):
         self.assertRaises(TypeError, func_none2, s='boogie',
                           date=None, date2=True)
 
-        
+
+    def testCustom(self):
+        @argcheck(number)
+        def func(n):
+            pass
+        func(10)
+
+    def testDisable(self):
+        argcheck.disable()
+        @argcheck(str)
+        def func(s):
+            pass
+        func(10)
+        argcheck.enable()
+
+    def testErrorHandling(self):
+        self.assertRaises(TypeError, argcheck(str), True)
+        self.assertRaises(TypeError, argcheck(int), lambda **x: None)
+        self.assertRaises(TypeError, argcheck(int), lambda : None)
+        self.assertRaises(TypeError, argcheck(int), lambda x='str': None)
+
 if __name__ == '__main__':
     unittest.main()
